@@ -68,11 +68,3 @@ class PublishManager(object):
 
 # singleton, used by all instances of WslinkWebSocketServerProtocol
 publishManager = PublishManager()
-
-# from http://www.jsonrpc.org/specification, section 5.1
-METHOD_NOT_FOUND = -32601
-AUTHENTICATION_ERROR = -32000
-EXCEPTION_ERROR = -32001
-RESULT_SERIALIZE_ERROR = -32002
-# used in client JS code:
-CLIENT_ERROR = -32099
